==> kisters.water.rest_client-0.0.7.tar.gz: kisters.water.rest_client-0.0.7/kisters/water/rest_client/rest_client.py <==
from typing import Iterable, List, Optional, Union

import requests
import msgpack

from .auth import Authentication


class RESTClient:
    def __init__(self, url: str, *, authentication: Authentication = None):
        super().__init__()
        self._url = url.rstrip("/")
        self._auth = authentication
        self._session = requests.Session()

    @property
    def url(self):
        return self._url

    @property
    def session(self):
        return self._session

    def _construct_url(
        self, resource: Optional[Union[str, Iterable[str]]] = None
    ) -> str:
        if resource is None:
            return self.url
        if isinstance(resource, str):
            return "/".join((self.url, resource))
        return "/".join((self.url, *resource))

    @staticmethod
    def _verify_response(response):
        if response.status_code == 422:
            raise ValueError(response.json())
        response.raise_for_status()

    def get(
        self,
        resource: Optional[Union[str, Iterable[str]]] = None,
        *,
        parameters: Optional[dict] = None,
        data: Optional[Union[dict, List[dict]]] = None,
        headers: Optional[dict] = None,
        msgpack_data: Optional[bool] = None,
    ) -> Union[dict, List[dict]]:
        """Get data located at a resource"""
        return self.request(
            "get",
            resource,
            parameters=parameters,
            data=data,
            headers=headers,
            msgpack_data=msgpack_data,
        )

    def put(
        self,
        resource: Optional[Union[str, Iterable[str]]] = None,
        *,
        parameters: Optional[dict] = None,
        data: Optional[Union[dict, List[dict]]] = None,
        headers: Optional[dict] = None,
        msgpack_data: Optional[bool] = None,
    ):
        """Overwrite data located at a resource"""
        return self.request(
            "put",
            resource,
            parameters=parameters,
            data=data,
            headers=headers,
            msgpack_data=msgpack_data,
        )

    def post(
        self,
        resource: Optional[Union[str, Iterable[str]]] = None,
        *,
        parameters: Optional[dict] = None,
        data: Optional[Union[dict, List[dict]]] = None,
        headers: Optional[dict] = None,
        msgpack_data: Optional[bool] = None,
    ):
        """Send data to a resource"""
        return self.request(
            "post",
            resource,
            parameters=parameters,
            data=data,
            headers=headers,
            msgpack_data=msgpack_data,
        )

    def delete(
        self,
        resource: Optional[Union[str, Iterable[str]]] = None,
        *,
        parameters: Optional[dict] = None,
        data: Optional[Union[dict, List[dict]]] = None,
        headers: Optional[dict] = None,
        msgpack_data: Optional[bool] = None,
    ):
        """Delete data located at a resource"""
        return self.request(
            "delete",
            resource,
            parameters=parameters,
            data=data,
            headers=headers,
            msgpack_data=msgpack_data,
        )

    def request(
        self,
        method: str,
        resource: Optional[Union[str, Iterable[str]]] = None,
        *,
        parameters: Optional[dict] = None,
        data: Optional[Union[dict, List[dict]]] = None,
        headers: Optional[dict] = None,
        msgpack_data: Optional[bool] = None,
    ):
        headers = headers or {}
        if self._auth:
            headers["Authorization"] = f"Bearer {self._auth.get_access_token()}"
        if msgpack_data:
            headers["accept"] = "application/x-msgpack"
        json = None
        if data is not None:
            if msgpack_data:
                data = msgpack.packb(data)
                headers["content-type"] = "application/x-msgpack"
            else:
                json = data
                data = None
        resp = self._session.request(
            method,
            self._construct_url(resource),
            params=parameters,
            json=json,
            data=data,
            headers=headers,
        )
        self._verify_response(resp)
        if resp.headers.get("Content-Type") == "application/x-msgpack":
            return msgpack.unpackb(resp.content, raw=False)
        if resp.headers.get("Content-Type") == "application/json":
            return resp.json()
        return resp

==> kisters.water.rest_client-0.0.8.tar.gz: kisters.water.rest_client-0.0.8/kisters/water/rest_client/rest_client.py <==
import functools
from typing import Iterable, Optional, Union

import msgpack
import requests

from .auth import Authentication


class RESTClient:
    def __init__(self, url: str, *, authentication: Authentication = None):
        self._url = url.rstrip("/")
        self._auth = authentication
        self._session = requests.Session()

    @property
    def url(self):
        return self._url

    @property
    def session(self):
        return self._session

    def _construct_url(
        self, resource: Optional[Union[str, Iterable[str]]] = None
    ) -> str:
        if resource is None:
            return self.url
        if isinstance(resource, str):
            return "/".join((self.url, resource))
        return "/".join((self.url, *resource))

    def __getattr__(self, name):
        return functools.partial(self.request, name)

    @staticmethod
    def _verify_response(response):
        if response.status_code == 422:
            raise ValueError(response.json())
        response.raise_for_status()

    def request(
        self,
        method: str,
        resource: Optional[Union[str, Iterable[str]]] = None,
        *,
        msgpack_json: Optional[bool] = None,
        **kwargs,
    ):
        headers = kwargs.pop("headers", {})
        if self._auth:
            headers["Authorization"] = f"Bearer {self._auth.get_access_token()}"
        if msgpack_json:
            headers["accept"] = "application/x-msgpack"
            if kwargs.get("json"):
                if kwargs.get("data"):
                    raise ValueError(
                        "Option msgpack_json requires data kwarg to be unset"
                    )
                else:
                    kwargs["data"] = msgpack.packb(kwargs.pop("json"))
                    headers["content-type"] = "application/x-msgpack"
        resp = self._session.request(
            method, self._construct_url(resource), headers=headers, **kwargs
        )
        self._verify_response(resp)
        if resp.headers.get("Content-Type") == "application/x-msgpack":
            return msgpack.unpackb(resp.content, raw=False)
        if resp.headers.get("Content-Type") == "application/json":
            return resp.json()
        return resp
